@@ -1380,7 +1380,7 @@ def set_common_pglog():
 
    SETPGLOG("TMPDIR", '')
    if not PGLOG['TMPDIR']:
-      PGLOG['TMPDIR'] = "/lustre/desc1/gdex/scratch/" + PGLOG['CURUID']
+      PGLOG['TMPDIR'] = "/lustre/desc1/scratch/" + PGLOG['CURUID']
       os.environ['TMPDIR'] = PGLOG['TMPDIR']
 
    # empty diretory for HOST-sync
@@ -1393,10 +1393,6 @@ def set_common_pglog():
 # check and return TMPSYNC path, and add it if not exists
 #
 def get_tmpsync_path():
-
-   if 'DSSHOME' in PGLOG and PGLOG['DSSHOME'] and not op.exists(PGLOG['TMPSYNC']):
-      pgsystem("mkdir " + PGLOG['TMPSYNC'], 0, LGWNEX, 4)
-      pgsystem("chmod 775 " + PGLOG['TMPSYNC'], LOGWRN, 4)
    return PGLOG['TMPSYNC']
 
 #
